@@ -167,7 +167,11 @@ static eclean()
 
 static epush(re)struct EXP *re;
 {
+#if 0
   obstack_ptr_grow (&osStack, re);
+#else
+  obstack_grow(&osStack, &re, sizeof (void *));
+#endif
 }
 
 /******************************************************************************
